NLSL: eprprm Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Functions/Subroutines | Variables
eprprm Module Reference

## Functions/Subroutines
subroutine | prm_ptr_init

## Variables
double precision, dimension(nfprm), target, save | fepr
integer, dimension(niprm), target, save | iepr
double precision, pointer, save | phase
double precision, pointer, save | gib0
double precision, pointer, save | gib2
double precision, pointer, save | wxx
double precision, pointer, save | wyy
double precision, pointer, save | wzz
double precision, pointer, save | gxx
double precision, pointer, save | gyy
double precision, pointer, save | gzz
double precision, pointer, save | axx
double precision, pointer, save | ayy
double precision, pointer, save | azz
double precision, pointer, save | dx
double precision, pointer, save | dy
double precision, pointer, save | dz
double precision, pointer, save | pml
double precision, pointer, save | pmxy
double precision, pointer, save | pmzz
double precision, pointer, save | djf
double precision, pointer, save | djfprp
double precision, pointer, save | oss
double precision, pointer, save | psi
double precision, pointer, save | ald
double precision, pointer, save | bed
double precision, pointer, save | gad
double precision, pointer, save | alm
double precision, pointer, save | bem
double precision, pointer, save | gam
double precision, pointer, save | c20
double precision, pointer, save | c22
double precision, pointer, save | c40
double precision, pointer, save | c42
double precision, pointer, save | c44
double precision, pointer, save | lb
double precision, pointer, save | dc20
double precision, pointer, save | b0
double precision, pointer, save | gamman
double precision, pointer, save | cgtol
double precision, pointer, save | shiftr
double precision, pointer, save | shifti
double precision, pointer, save | range
double precision, pointer, save | fldi
double precision, pointer, save | dfld
integer, pointer, save | in2
integer, pointer, save | ipdf
integer, pointer, save | ist
integer, pointer, save | ml
integer, pointer, save | mxy
integer, pointer, save | mzz
integer, pointer, save | lemx
integer, pointer, save | lomx
integer, pointer, save | kmn
integer, pointer, save | kmx
integer, pointer, save | mmn
integer, pointer, save | mmx
integer, pointer, save | ipnmx
integer, pointer, save | nort
integer, pointer, save | nstep
integer, pointer, save | nfld
integer, pointer, save | ideriv
integer, pointer, save | iwflg
integer, pointer, save | igflg
integer, pointer, save | iaflg
integer, pointer, save | irflg
integer, pointer, save | jkmn
integer, pointer, save | jmmn
integer, pointer, save | ndim
double precision, save | a0
double precision, save | g0
double precision, save | w0
double precision, save | expl
double precision, save | expkxy
double precision, save | expkzz
double precision, dimension(5), save | faa
double precision, dimension(5), save | fgm
double precision, dimension(5), save | fwm
double precision, dimension(2, 5), save | fam
double precision, dimension(2, 5), save | fgd
double precision, dimension(2, 5), save | fad
double precision, dimension(2, 5), save | fwd
double precision, dimension(5, 5), save | cpot
double precision, dimension(5, 5), save | xlk
integer, save | itype
integer, save | ipt
integer, save | itm
integer, save | itd
integer, save | ipsi0
integer, save | lband
integer, save | kband
integer, save | ldelta
integer, save | kdelta
integer, save | lptmx
integer, save | kptmx
integer, save | neltot
integer, save | nelv
integer, save | nelre
integer, save | nelim
integer, save | ncgstp
integer, parameter | iphase =1
integer, parameter | igib0 =2
integer, parameter | igib2 =3
integer, parameter | iwxx =4
integer, parameter | iwzz =6
integer, parameter | igxx =7
integer, parameter | igzz =9
integer, parameter | iaxx =10
integer, parameter | iazz =12
integer, parameter | idx =13
integer, parameter | idz =15
integer, parameter | ipml =16
integer, parameter | ipmxy =17
integer, parameter | ipmzz =18
integer, parameter | idjf =19
integer, parameter | idjfprp =20
integer, parameter | ioss =21
integer, parameter | ipsi =22
integer, parameter | iald =23
integer, parameter | ibed =24
integer, parameter | igad =25
integer, parameter | ialm =26
integer, parameter | igam =28
integer, parameter | ic20 =29
integer, parameter | ic44 =33
integer, parameter | ilb =34
integer, parameter | idc20 =35
integer, parameter | ib0 =36
integer, parameter | igaman =37
integer, parameter | icgtol =38
integer, parameter | ishift =39
integer, parameter | irange =41
integer, parameter | ifldi =42
integer, parameter | idfld =43
integer, parameter | iin2 =1
integer, parameter | iipdf =2
integer, parameter | iist =3
integer, parameter | iml =4
integer, parameter | ilemx =7
integer, parameter | inort =14
integer, parameter | instep =15
integer, parameter | infld =16
integer, parameter | iiderv =17
integer, parameter | iiwflg =18
integer, parameter | iigflg =19
integer, parameter | iiaflg =20
integer, parameter | iirflg =21
integer, parameter | indim =24
integer, parameter | iwyy =5
integer, parameter | igyy =8
integer, parameter | iayy =11
integer, parameter | idy =14
integer, parameter | ibem =27
integer, parameter | ic22 =30
integer, parameter | ic40 =31
integer, parameter | ic42 =32
integer, parameter | ishifti =40
integer, parameter | imxy =5
integer, parameter | imzz =6
integer, parameter | ilomx =8
integer, parameter | ikmn =9
integer, parameter | ikmx =10
integer, parameter | immn =11
integer, parameter | immx =12
integer, parameter | iipnmx =13
integer, parameter | ijkmn =22
integer, parameter | ijmmn =23
integer, parameter | igamman =IGAMAN
integer, parameter | ishiftr =ISHIFT
integer, parameter | iideriv =IIDERV

## Function/Subroutine Documentation

subroutine eprprm::prm_ptr_init | ( |  | ) |

Definition at line 145 of file eprprm.f90.

Here is the caller graph for this function:

## Variable Documentation

double precision, save eprprm::a0

Definition at line 78 of file eprprm.f90.

double precision, pointer, save eprprm::ald

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::alm

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::axx

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::ayy

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::azz

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::b0

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::bed

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::bem

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::c20

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::c22

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::c40

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::c42

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::c44

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::cgtol

Definition at line 58 of file eprprm.f90.

double precision, dimension(5,5), save eprprm::cpot

Definition at line 78 of file eprprm.f90.

double precision, pointer, save eprprm::dc20

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::dfld

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::djf

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::djfprp

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::dx

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::dy

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::dz

Definition at line 58 of file eprprm.f90.

double precision, save eprprm::expkxy

Definition at line 78 of file eprprm.f90.

double precision, save eprprm::expkzz

Definition at line 78 of file eprprm.f90.

double precision, save eprprm::expl

Definition at line 78 of file eprprm.f90.

double precision, dimension(5), save eprprm::faa

Definition at line 78 of file eprprm.f90.

double precision, dimension(2,5), save eprprm::fad

Definition at line 78 of file eprprm.f90.

double precision, dimension(2,5), save eprprm::fam

Definition at line 78 of file eprprm.f90.

double precision, dimension(nfprm), target, save eprprm::fepr

Definition at line 55 of file eprprm.f90.

double precision, dimension(2,5), save eprprm::fgd

Definition at line 78 of file eprprm.f90.

double precision, dimension(5), save eprprm::fgm

Definition at line 78 of file eprprm.f90.

double precision, pointer, save eprprm::fldi

Definition at line 58 of file eprprm.f90.

double precision, dimension(2,5), save eprprm::fwd

Definition at line 78 of file eprprm.f90.

double precision, dimension(5), save eprprm::fwm

Definition at line 78 of file eprprm.f90.

double precision, save eprprm::g0

Definition at line 78 of file eprprm.f90.

double precision, pointer, save eprprm::gad

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::gam

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::gamman

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::gib0

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::gib2

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::gxx

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::gyy

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::gzz

Definition at line 58 of file eprprm.f90.

integer, pointer, save eprprm::iaflg

Definition at line 69 of file eprprm.f90.

integer, parameter eprprm::iald =23

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::ialm =26

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::iaxx =10

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::iayy =11

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::iazz =12

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::ib0 =36

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::ibed =24

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::ibem =27

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::ic20 =29

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::ic22 =30

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::ic40 =31

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::ic42 =32

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::ic44 =33

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::icgtol =38

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::idc20 =35

Definition at line 92 of file eprprm.f90.

integer, pointer, save eprprm::ideriv

Definition at line 69 of file eprprm.f90.

integer, parameter eprprm::idfld =43

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::idjf =19

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::idjfprp =20

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::idx =13

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::idy =14

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::idz =15

Definition at line 92 of file eprprm.f90.

integer, dimension(niprm), target, save eprprm::iepr

Definition at line 56 of file eprprm.f90.

integer, parameter eprprm::ifldi =42

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::igad =25

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::igam =28

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::igaman =37

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::igamman =IGAMAN

Definition at line 116 of file eprprm.f90.

integer, pointer, save eprprm::igflg

Definition at line 69 of file eprprm.f90.

integer, parameter eprprm::igib0 =2

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::igib2 =3

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::igxx =7

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::igyy =8

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::igzz =9

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::iiaflg =20

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::iideriv =IIDERV

Definition at line 116 of file eprprm.f90.

integer, parameter eprprm::iiderv =17

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::iigflg =19

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::iin2 =1

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::iipdf =2

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::iipnmx =13

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::iirflg =21

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::iist =3

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::iiwflg =18

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::ijkmn =22

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::ijmmn =23

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::ikmn =9

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::ikmx =10

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::ilb =34

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::ilemx =7

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::ilomx =8

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::iml =4

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::immn =11

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::immx =12

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::imxy =5

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::imzz =6

Definition at line 108 of file eprprm.f90.

integer, pointer, save eprprm::in2

Definition at line 69 of file eprprm.f90.

integer, parameter eprprm::indim =24

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::infld =16

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::inort =14

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::instep =15

Definition at line 101 of file eprprm.f90.

integer, parameter eprprm::ioss =21

Definition at line 92 of file eprprm.f90.

integer, pointer, save eprprm::ipdf

Definition at line 69 of file eprprm.f90.

integer, parameter eprprm::iphase =1

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::ipml =16

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::ipmxy =17

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::ipmzz =18

Definition at line 92 of file eprprm.f90.

integer, pointer, save eprprm::ipnmx

Definition at line 69 of file eprprm.f90.

integer, parameter eprprm::ipsi =22

Definition at line 92 of file eprprm.f90.

integer, save eprprm::ipsi0

Definition at line 82 of file eprprm.f90.

integer, save eprprm::ipt

Definition at line 82 of file eprprm.f90.

integer, parameter eprprm::irange =41

Definition at line 92 of file eprprm.f90.

integer, pointer, save eprprm::irflg

Definition at line 69 of file eprprm.f90.

integer, parameter eprprm::ishift =39

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::ishifti =40

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::ishiftr =ISHIFT

Definition at line 116 of file eprprm.f90.

integer, pointer, save eprprm::ist

Definition at line 69 of file eprprm.f90.

integer, save eprprm::itd

Definition at line 82 of file eprprm.f90.

integer, save eprprm::itm

Definition at line 82 of file eprprm.f90.

integer, save eprprm::itype

Definition at line 82 of file eprprm.f90.

integer, pointer, save eprprm::iwflg

Definition at line 69 of file eprprm.f90.

integer, parameter eprprm::iwxx =4

Definition at line 92 of file eprprm.f90.

integer, parameter eprprm::iwyy =5

Definition at line 108 of file eprprm.f90.

integer, parameter eprprm::iwzz =6

Definition at line 92 of file eprprm.f90.

integer, pointer, save eprprm::jkmn

Definition at line 69 of file eprprm.f90.

integer, pointer, save eprprm::jmmn

Definition at line 69 of file eprprm.f90.

integer, save eprprm::kband

Definition at line 82 of file eprprm.f90.

integer, save eprprm::kdelta

Definition at line 82 of file eprprm.f90.

integer, pointer, save eprprm::kmn

Definition at line 69 of file eprprm.f90.

integer, pointer, save eprprm::kmx

Definition at line 69 of file eprprm.f90.

integer, save eprprm::kptmx

Definition at line 82 of file eprprm.f90.

double precision, pointer, save eprprm::lb

Definition at line 58 of file eprprm.f90.

integer, save eprprm::lband

Definition at line 82 of file eprprm.f90.

integer, save eprprm::ldelta

Definition at line 82 of file eprprm.f90.

integer, pointer, save eprprm::lemx

Definition at line 69 of file eprprm.f90.

integer, pointer, save eprprm::lomx

Definition at line 69 of file eprprm.f90.

integer, save eprprm::lptmx

Definition at line 82 of file eprprm.f90.

integer, pointer, save eprprm::ml

Definition at line 69 of file eprprm.f90.

integer, pointer, save eprprm::mmn

Definition at line 69 of file eprprm.f90.

integer, pointer, save eprprm::mmx

Definition at line 69 of file eprprm.f90.

integer, pointer, save eprprm::mxy

Definition at line 69 of file eprprm.f90.

integer, pointer, save eprprm::mzz

Definition at line 69 of file eprprm.f90.

integer, save eprprm::ncgstp

Definition at line 82 of file eprprm.f90.

integer, pointer, save eprprm::ndim

Definition at line 69 of file eprprm.f90.

integer, save eprprm::nelim

Definition at line 82 of file eprprm.f90.

integer, save eprprm::nelre

Definition at line 82 of file eprprm.f90.

integer, save eprprm::neltot

Definition at line 82 of file eprprm.f90.

integer, save eprprm::nelv

Definition at line 82 of file eprprm.f90.

integer, pointer, save eprprm::nfld

Definition at line 69 of file eprprm.f90.

integer, pointer, save eprprm::nort

Definition at line 69 of file eprprm.f90.

integer, pointer, save eprprm::nstep

Definition at line 69 of file eprprm.f90.

double precision, pointer, save eprprm::oss

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::phase

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::pml

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::pmxy

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::pmzz

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::psi

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::range

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::shifti

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::shiftr

Definition at line 58 of file eprprm.f90.

double precision, save eprprm::w0

Definition at line 78 of file eprprm.f90.

double precision, pointer, save eprprm::wxx

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::wyy

Definition at line 58 of file eprprm.f90.

double precision, pointer, save eprprm::wzz

Definition at line 58 of file eprprm.f90.

double precision, dimension(5,5), save eprprm::xlk

Definition at line 78 of file eprprm.f90.